# Filtering drivers.
#
# Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
# Copyright:: Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
# License::   GPLv3+: GNU General Public License version 3 or later
#
# Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>

#--
#     ___    ____  __    ___   _________
#    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
#   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
#  / __  |/ /_/ / /___/ / /|  /  / /
# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
#
# This file is part of adlint-postfilter.
#
# adlint-postfilter is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# adlint-postfilter is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# adlint-postfilter.  If not, see <http://www.gnu.org/licenses/>.
#
#++

require "fileutils"

require "adlint/postfilter/command"

module AdLint #:nodoc:

  module Postfilter
    def install_config_template(config_fpath)
      FileUtils.cp(File.expand_path("conf.d/adlint_postfilter.yml", $etcdir),
                   config_fpath)
    end
    module_function :install_config_template

    def transform_makefile(makefile_fpath)
      orig_fpath = makefile_fpath.add_ext(".orig")
      FileUtils.mv(makefile_fpath, orig_fpath)

      File.open(makefile_fpath, "w") do |dst_io|
        dst_io.puts File.open(orig_fpath, "r") { |src_io|
          src_io.each_line.map do |line|
            case line
            when /^(ADLINT =) (.*adlint)$/,
                 /^(ADLINT_SMA =) (.*adlint_sma)$/,
                 /^(ADLINT_CHK =) (.*adlint_chk)$/
              "#{$1} adlint_flt -A #{$2}"
            when /^(ADLINT_CMA =) (.*adlint_cma)$/
              "#{$1} adlint_flt -V $(VPATH) -A #{$2}"
            else
              line.chomp
            end
          end
        }
      end
    end
    module_function :transform_makefile

    def run(config_fpath, command_line, src_vpath)
      command = AnalysisCommand.for(command_line, config_fpath, src_vpath)
      command.execute.exitstatus
    end
    module_function :run
  end

end
